@@ -5,6 +5,9 @@ from pyzbar import pyzbar
 ##        block = image[ weak_row_start: weak_row_start+weak_height,
 ##                              x + block_offset : x + block_offset + block_width]
 from algorithm import alg
+
+MIN_BARCODE_WIDTH = 100
+MIN_BARCODE_HEIGH = 900
 def qrCut(image):
     image = alg.balance(image,200)
     gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
@@ -12,18 +15,26 @@ def qrCut(image):
 
     reverse = cv2.bitwise_not(thresh)
 
-    kernel = np.ones((40,30), np.uint8)
+    kernel = np.ones((35,2), np.uint8)
 #    dilation = cv2.erode(morph, kernel, iterations=1)
     dilation = cv2.dilate(reverse, kernel, iterations=1)
-#     cv2.imshow("dilation", dilation)
-#     cv2.waitKey(0)
+
+##    cv2.imshow("thresh", thresh)
+##    cv2.imshow("dilation", dilation)
+##    cv2.waitKey(0)
 
     contours, hierarchy = cv2.findContours(dilation, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_NONE)
     if len(contours) != 0:
 
+        for each in contours:
+            x,y,w,h = cv2.boundingRect(each)
+            if w > MIN_BARCODE_WIDTH and h >MIN_BARCODE_HEIGH:
+                break;
+        else:
+            return thresh
         # find the biggest countour (c) by the area
-        c = max(contours, key = cv2.contourArea)
-        x,y,w,h = cv2.boundingRect(c)
+##        c = max(contours, key = cv2.contourArea)
+##        x,y,w,h = cv2.boundingRect(c)
 
         cut = thresh[y:y+h,x:x+w]
 #         target = reverse[y:y+h,x:x+w]
@@ -31,9 +42,9 @@ def qrCut(image):
         target = cv2.morphologyEx(cut, cv2.MORPH_OPEN, kernel)
 # 
 #         target = cv2.bitwise_not(target)
-#        cv2.imshow("target", target)
-#        cv2.imshow("reverse", reverse)
-#        cv2.waitKey(0)
+##        cv2.imshow("target", target)
+##        cv2.imshow("reverse", reverse)
+##        cv2.waitKey(0)
 #         print('write target')
 #        cv2.imwrite(str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg', target)
         return target
