@@ -110,11 +110,6 @@ class TestChipHandlerThread (threading.Thread):
         if result[RESULT_ERROR_CODE] == DEVICE_STATE_TAKING_PHOTO:
             self.checkingStart(result[RESULT_SLOT_NUMBER])
             self.qGui.put(result)
-        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_FLIP:
-            #print('manual flip')
-            self.qGui.put(result)
-        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_INVALID_QR:
-            self.qGui.put(result)
         elif result[RESULT_CASSETTE_ID] == '':
             self.qGui.put(result)
         elif self.startCheck[result[RESULT_SLOT_NUMBER]] == True:
